/* Copyright Andrey N. Kuznetsov (Андрей Николаевич Кузнецов), linmedsoft@narod.ru
06.08.2008-12.06.2008, Almaty

Internationalization template.

This programme (template) is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 2, or (at your option) any
later version.
This programme is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this programme.  */
//---------------------------------------------------------------------------
#include "TLanguageForm.h"
//---------------------------------------------------------------------------
#include <qapplication.h>
#include <qlayout.h>
#include <qlabel.h>
#include <qframe.h>
#include <qpushbutton.h>
#include <qfile.h>
#include <qfileinfo.h>
#include <qtextstream.h>
#include <qtranslator.h>
#include <qtextcodec.h>
#include <qdir.h>
#include <qmessagebox.h>
//---------------------------------------------------------------------------
TLanguageForm::TLanguageForm(QWidget* pParent, const char* psName, bool bModal, WFlags Flag)
                            : QDialog(pParent, psName, bModal, Flag)
{
    if(!psName) setName("LanguageForm");
    
    sLocale = LoadLanguageSettingsSlot();
    if(sLocale.isEmpty()) sLocale = QTextCodec::locale();
    
    #if defined(Q_OS_UNIX)
        sLocale.truncate(2);
    #endif
    
    QString sQmFile = QString("TLanguageForm_" + sLocale + ".qm");
    QString sQmPath = qApp->applicationDirPath();
    sQmFile = sQmPath + "/" + sQmFile;
    
    QFileInfo QmFileInfo(sQmFile);
    if(!QmFileInfo.exists())
    {
        QString sErrorMessage = "Can't find a translation file for the language \"" 
                                + sLocale + "\"." + "\nIt will be used English (en) as a default language.";
        QMessageBox::warning(0, "Translation error", sErrorMessage);
        sLocale = "en";
    }
    
    pTranslator = new QTranslator(0);
    
    pTranslator->load(sQmFile, ".");
    qApp->installTranslator(pTranslator);
    
    pMainLayout = new QVBoxLayout(this, 11, 5, "MainLayout");

    pMessageLabel = new QLabel(this, "MessageLabel");
    pMainLayout->addWidget(pMessageLabel);
    
    pSeparator = new QLabel(this, "Separator");
    pSeparator->setFrameStyle(QFrame::HLine | QFrame::Sunken);
    pSeparator->setLineWidth(1);
    pSeparator->setMargin(2);
    pMainLayout->addWidget(pSeparator);

    pButtonsLayout = new QHBoxLayout(pMainLayout, 5, "ButtonsLayout");
    
    pAcceptButton = new QPushButton(this, "AcceptButton");    
    pCancelButton = new QPushButton(this, "CancelButton");
    
    pButtonsLayout->addWidget(pAcceptButton);
    pButtonsLayout->addWidget(pCancelButton);
    pButtonsLayout->insertStretch(0, 0);

    resize(QSize(320, 120));

    SetStringsSlot();

    connect(pAcceptButton, SIGNAL(clicked()), this, SLOT(accept()));    
    connect(pCancelButton, SIGNAL(clicked()), this, SLOT(reject()));
}
//---------------------------------------------------------------------------
TLanguageForm::~TLanguageForm()
{
}
//---------------------------------------------------------------------------
void TLanguageForm::SetStringsSlot()
{
    setCaption(tr("Language Selection"));

    pMessageLabel->setText(tr("Click the \"Accept\" button to change the programme's language.\nSelected language will be used after restarting of the programme."));

    pAcceptButton->setText(tr("Accept"));
    pCancelButton->setText(tr("Cancel"));
}
//---------------------------------------------------------------------------
QString TLanguageForm::LoadLanguageSettingsSlot()
{
    QString sLanguage = "";
    
    QString sPath = QDir::homeDirPath() + "/.Translation";
    QString sSettingsPath = sPath + "/settings";
    QString sSettingsFilePath = sSettingsPath + "/settings.ini";
    if(QFile::exists(sSettingsFilePath))
    {
        QFile OutputFile(sSettingsFilePath);
        if(OutputFile.open(IO_ReadOnly))
        {
            QTextStream TextStream(&OutputFile);
            
            sLanguage = TextStream.readLine();
        }
    }
    else
    {
        QDir WorkingDirectory(sPath);
        QDir SettingsDirectory(sSettingsPath);
        if(SettingsDirectory.exists() == FALSE)
        {
            WorkingDirectory.mkdir((sPath), TRUE);
        }
        if(SettingsDirectory.exists() == FALSE)
        {
            SettingsDirectory.mkdir((sSettingsPath), TRUE);
        }
        QFile InputFile(sSettingsFilePath);
        if(InputFile.open(IO_WriteOnly))
        {
            InputFile.close();
        }
    }
    return sLanguage;
}
//---------------------------------------------------------------------------
