/* Copyright Andrey N. Kuznetsov (  ), linmedsoft@narod.ru
06.08.2008-12.06.2008, Almaty

Internationalization template.

This programme (template) is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 2, or (at your option) any
later version.
This programme is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this programme.  */
//---------------------------------------------------------------------------
#include "TMainForm.h"
#include "TLanguageForm.h"
//---------------------------------------------------------------------------
#include <qapplication.h>
#include <qtextcodec.h>
#include <qfile.h>
#include <qfileinfo.h>
#include <qtextstream.h>
#include <qtranslator.h>
#include <qaction.h>
#include <qmenubar.h>
#include <qpopupmenu.h>
#include <qdir.h>
#include <qstringlist.h>
#include <qtextcodec.h>
#include <qmessagebox.h>
#include <qstatusbar.h>
//---------------------------------------------------------------------------
TMainForm::TMainForm(QWidget* pParent, const char* psName, WFlags Flag)
                     : QMainWindow(pParent, psName, Flag)
{
    if(!psName) setName("MainForm");
    
    sLocale = LoadLanguageSettingsSlot();
    if(sLocale.isEmpty()) sLocale = QTextCodec::locale();
    
    #if defined(Q_OS_UNIX)
        sLocale.truncate(2);
    #endif
    
    QString sQmFile = QString("TMainForm_" + sLocale + ".qm");
    QString sQmPath = qApp->applicationDirPath();
    sQmFile = sQmPath + "/" + sQmFile;
    
    QFileInfo QmFileInfo(sQmFile);
    if(!QmFileInfo.exists())
    {
        QString sErrorMessage = "Can't find a translation file for the language \"" 
                                + sLocale + "\"." + "\nIt will be used English (en) as a default language.";
        QMessageBox::warning(0, "Translation error", sErrorMessage);
        sLocale = "en";
    }
    
    pTranslator = new QTranslator(0);
    pTranslator->load(sQmFile, ".");
    qApp->installTranslator(pTranslator);
    
    SetStringsSlot();
    
    CreateActionsSlot();
    
    CreateMenusSlot();
    
    statusBar();
    
    resize(QSize(600, 400));
}
//---------------------------------------------------------------------------
TMainForm::~TMainForm()
{
}
//---------------------------------------------------------------------------
QString TMainForm::LoadLanguageSettingsSlot()
{
    QString sLanguage = "";
    
    QString sPath = QDir::homeDirPath() + "/.Translation";
    QString sSettingsPath = sPath + "/settings";
    QString sSettingsFilePath = sSettingsPath + "/settings.ini";
    if(QFile::exists(sSettingsFilePath))
    {
        QFile OutputFile(sSettingsFilePath);
        if(OutputFile.open(IO_ReadOnly))
        {
            QTextStream TextStream(&OutputFile);
            
            sLanguage = TextStream.readLine();
        }
    }
    else
    {
        QDir WorkingDirectory(sPath);
        QDir SettingsDirectory(sSettingsPath);
        if(SettingsDirectory.exists() == FALSE)
        {
            WorkingDirectory.mkdir((sPath), TRUE);
        }
        if(SettingsDirectory.exists() == FALSE)
        {
            SettingsDirectory.mkdir((sSettingsPath), TRUE);
        }
        QFile InputFile(sSettingsFilePath);
        if(InputFile.open(IO_WriteOnly))
        {
            InputFile.close();
        }
    }
    return sLanguage;
}
//---------------------------------------------------------------------------
void TMainForm::CreateActionsSlot()
{
    pFileExitAction = new QAction(this, "FileExitAction", FALSE);
    pFileExitAction->setText(tr("Quit"));
    pFileExitAction->setMenuText(tr("Quit"));
    //pFileExitAction->setIconSet(QPixmap::fromMimeSource("exit.png"));
    pFileExitAction->setAccel(QKeySequence(tr("Ctrl+Q")));
    pFileExitAction->setStatusTip(tr("Finish the programme's work"));
    connect(pFileExitAction, SIGNAL(activated()), qApp, SLOT(quit()));
    
    pHelpAboutQtAction = new QAction(this, "HelpAboutQtAction", FALSE);
    pHelpAboutQtAction->setText(tr("About Qt"));
    pHelpAboutQtAction->setMenuText(tr("About Qt"));
    //pHelpAboutQtAction->setIconSet(QPixmap::fromMimeSource("Qt.png"));
    pHelpAboutQtAction->setAccel(QKeySequence(tr("F3")));
    pHelpAboutQtAction->setStatusTip(tr("Show the brief information about the Qt library"));
    connect(pHelpAboutQtAction, SIGNAL(activated()), this, SLOT(HelpAboutQtSlot()));
}
//---------------------------------------------------------------------------
void TMainForm::CreateMenusSlot()
{
    pFileMenu = new QPopupMenu(this);
    pFileExitAction->addTo(pFileMenu);
    
    pLanguageMenu = new QPopupMenu(this);
   
    QString sQmPath = qApp->applicationDirPath();
    QDir TranslationsFolder(sQmPath);
    QStringList sTranslationsFilesList = TranslationsFolder.entryList("TMainForm_*.qm");
    for(int i = 0; i < (int)sTranslationsFilesList.size(); ++i)
    {
        pTranslator->load(sTranslationsFilesList[i], sQmPath);
        QTranslatorMessage TranslatorMessage = pTranslator->findMessage("TMainForm", "English");
        QString sLanguage = TranslatorMessage.translation();
        short nLangID = pLanguageMenu->insertItem(sLanguage, this, SLOT(SwitchLanguageSlot(int)));
        pLanguageMenu->setItemParameter(nLangID, i);
        
        sTranslationsFilesList[i].remove(0, 10);
        sTranslationsFilesList[i].remove(2, 3);

        if(sLocale == sTranslationsFilesList[i])
        {
            pLanguageMenu->setItemChecked(nLangID, TRUE);
        }
    }
    
    pHelpMenu = new QPopupMenu(this);
    pHelpAboutQtAction->addTo(pHelpMenu);
    
    QString sQmFile = QString("TMainForm_" + sLocale + ".qm");
    sQmFile = sQmPath + "/" + sQmFile;
    pTranslator->load(sQmFile, ".");
    
    menuBar()->insertItem(tr("File"), pFileMenu);
    menuBar()->insertItem(tr("Language"), pLanguageMenu);
    menuBar()->insertItem("?", pHelpMenu);
}
//---------------------------------------------------------------------------
void TMainForm::SetStringsSlot()
{
    setCaption(tr("Main Window"));
}
//---------------------------------------------------------------------------
void TMainForm::SwitchLanguageSlot(int iLanguage)
{
    TLanguageForm* pLanguageDialog = new TLanguageForm(this);
    if(pLanguageDialog->exec() == QDialog::Accepted)
    {
        QString sLanguage;
    
        switch(iLanguage)
        {
            case 0: sLanguage = "en"; break;
            case 1: sLanguage = "it"; break;
            case 2: sLanguage = "ru"; break;
            default: sLanguage = "en";
        }
        
        SaveLanguageSettingsSlot(sLanguage);
    }

    for(int i = 0; i < (int)pLanguageMenu->count(); ++i)
    {
        pLanguageMenu->setItemChecked(pLanguageMenu->idAt(i), i == iLanguage);
    }
}
//---------------------------------------------------------------------------
void TMainForm::HelpAboutQtSlot()
{
    QMessageBox::aboutQt(this, tr("Main Window"));
}
//---------------------------------------------------------------------------
void TMainForm::SaveLanguageSettingsSlot(QString& sLanguage)
{
    QString sPath = QDir::homeDirPath() + "/.Translation";
    QString sSettingsPath = sPath + "/settings";
    QString sSettingsFilePath = sSettingsPath + "/settings.ini";
    QDir WorkingDirectory(sPath);
    QDir SettingsDirectory(sSettingsPath);
    if(WorkingDirectory.exists() == FALSE)
    {
        WorkingDirectory.mkdir((sPath), TRUE);
    }
    if(SettingsDirectory.exists() == FALSE)
    {
        SettingsDirectory.mkdir((sSettingsPath), TRUE);
    }
    QFile InputFile(sSettingsFilePath);
    if(InputFile.open(IO_WriteOnly))
    {
        QTextStream TextStream(&InputFile);
        TextStream << sLanguage;
        InputFile.close();
    }
}
//---------------------------------------------------------------------------
